
local StoneGateV5 = ...

-- Apply building asset processor
StoneGateV5:registerAssetProcessor("models/decorations/decoration.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})
StoneGateV5:registerAssetProcessor("models/decorations/pinion.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})

-- Create default minor decoration part registering function 
function registerDefaultMinorDecorationPart(_nameFbxFile, _nameFbx, _nameAsset, _stoneCost)
    StoneGateV5:registerAssetId("models/decorations/" .. _nameFbxFile .. ".fbx/Prefab/decoration/Minor/" .. _nameFbx .. "Part", StoneGateSetPrefix .. "_DECORATION_" .. _nameAsset .. "_PREFAB")

    StoneGateV5:register({
	DataType = "BUILDING_PART",
	Id = StoneGateSetPrefix .. "_DECORATION_" .. _nameAsset .. "_PART",
	Name = StoneGateSetPrefix .. "_DECORATION_" .. _nameAsset .. "_NAME",
	Description = StoneGateSetPrefix .. "_DECORATION_" .. _nameAsset .. "_DESC",
	Category = "DECORATION",
	Mover = { DataType = "BUILDING_PART_MOVER_INSTANCE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = StoneGateSetPrefix .. "_DECORATION_" .. _nameAsset .. "_PREFAB",
                IsPreviewGroundVisible = false
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "STONE", Quantity = _stoneCost }
		}
	}
    })

    StoneGateV5:registerPrefabComponent("models/decorations/" .. _nameFbxFile .. ".fbx/Prefab/decoration/Minor/" .. _nameFbx .. "Part", {
	DataType = "COMP_BUILDING_PART",
	BuildingPartType = "MINOR", -- Snaps the decoration only on minor attach nodes (here only on the facades)
  	HasBuildingZone = false,
	BuildingZone = { 0, 0 }
    })
end

registerDefaultMinorDecorationPart("decoration", "ChimneyBase", "CHIMNEY_BASE", 0)
registerDefaultMinorDecorationPart("decoration", "PointedRoofBase", "POINTED_ROOF_BASE", 0)
registerDefaultMinorDecorationPart("decoration", "DecorationDoorA", "DOOR_A", 1)
registerDefaultMinorDecorationPart("decoration", "DecorationDoorB", "DOOR_B", 1)
registerDefaultMinorDecorationPart("decoration", "DecorationDoorMA", "DOOR_MA", 1)
registerDefaultMinorDecorationPart("decoration", "DecorationDoorMB", "DOOR_MB", 1)
registerDefaultMinorDecorationPart("pinion", "PinionA", "PINION_A", 2)
registerDefaultMinorDecorationPart("pinion", "PinionB", "PINION_B", 2)
registerDefaultMinorDecorationPart("pinion", "PinionC", "PINION_C", 0)
registerDefaultMinorDecorationPart("pinion", "PinionD", "PINION_D", 0)
registerDefaultMinorDecorationPart("pinion", "PinionE", "PINION_E", 0)
registerDefaultMinorDecorationPart("pinion", "PinionF", "PINION_F", 0)
registerDefaultMinorDecorationPart("pinion", "PinionG", "PINION_G", 0)
registerDefaultMinorDecorationPart("pinion", "PinionH", "PINION_H", 0)
registerDefaultMinorDecorationPart("pinion", "PinionI", "PINION_I", 0)
registerDefaultMinorDecorationPart("pinion", "PinionJ", "PINION_J", 0)

-- Create default major decoration part registering function 
function registerDefaultMajorDecorationPart(_nameFbx, _nameAsset, _stoneCost, _buildingZone)
    StoneGateV5:registerAssetId("models/decorations/decoration.fbx/Prefab/decoration/Minor/" .. _nameFbx .. "Part", StoneGateSetPrefix .. "_DECORATION_" .. _nameAsset .. "_PREFAB")

    StoneGateV5:register({
	DataType = "BUILDING_PART",
	Id = StoneGateSetPrefix .. "_DECORATION_" .. _nameAsset .. "_PART",
	Name = StoneGateSetPrefix .. "_DECORATION_" .. _nameAsset .. "_NAME",
	Description = StoneGateSetPrefix .. "_DECORATION_" .. _nameAsset .. "_DESC",
	Category = "DECORATION",
	Mover = { DataType = "BUILDING_PART_MOVER_INSTANCE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = StoneGateSetPrefix .. "_DECORATION_" .. _nameAsset .. "_PREFAB",
                IsPreviewGroundVisible = false
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "STONE", Quantity = _stoneCost }
		}
	}
    })
    StoneGateV5:registerPrefabComponent("models/decorations/decoration.fbx/Prefab/decoration/Minor/" .. _nameFbx .. "Part", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = _buildingZone
    })
end

registerDefaultMajorDecorationPart("Buttress", "BUTTRESS", 2, { 1, 2 })

-- Create default door decoration part registering function 
function registerDefaultDoorDecorationPart(_nameFbx, _nameAsset, _stoneCost)
    StoneGateV5:registerAssetId("models/decorations/decoration.fbx/Prefab/decoration/Entrance/" .. _nameFbx .. "Part", StoneGateSetPrefix .. "_ENTRANCE_" .. _nameAsset .. "_PREFAB")

    StoneGateV5:register({
	DataType = "BUILDING_PART",
	Id = StoneGateSetPrefix .. "_ENTRANCE_" .. _nameAsset .. "_PART",
	Name = StoneGateSetPrefix .. "_ENTRANCE_" .. _nameAsset .. "_NAME",
	Description = StoneGateSetPrefix .. "_ENTRANCE_" .. _nameAsset .. "_DESC",
	Category = "DOOR",
	Mover = { DataType = "BUILDING_PART_MOVER_INSTANCE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = StoneGateSetPrefix .. "_ENTRANCE_" .. _nameAsset .. "_PREFAB",
                IsPreviewGroundVisible = false
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "STONE", Quantity = _stoneCost }
		}
	}
    })

-- Register grounding components
    StoneGateV5:registerPrefabComponent("models/decorations/decoration.fbx/Prefab/decoration/Entrance/" .. _nameFbx .. "Part", {
	DataType = "COMP_GROUNDED"
    })

    StoneGateV5:registerPrefabComponent("models/decorations/decoration.fbx/Prefab/decoration/Entrance/" .. _nameFbx .. "Part", {
	DataType = "COMP_BUILDING_PART",
	BuildingPartType = "DOOR", -- Allows the door to be used as entrance
	HasBuildingZone = true,
	BuildingZone = { 1, 1 }
    })
end

registerDefaultDoorDecorationPart("DoorA", "DOOR_A", 1)
registerDefaultDoorDecorationPart("DoorB", "DOOR_B", 1)
